==> com.liferay.dynamic.data.mapping.form.renderer-5.0.69.jar: META-INF/resources/js/util/formId.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@5.0.69/js/util/formId.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-dom'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.getFormTitle = exports.getFormId = exports.getFormNode = void 0;

    var _metalDom = _interopRequireDefault(require("frontend-js-metal-web$metal-dom"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    /**
     * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
     * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
     */
    var getFormNode = function getFormNode(element) {
      return _metalDom.default.closest(element, 'form');
    };

    exports.getFormNode = getFormNode;

    var getFormId = function getFormId(form) {
      return form === null || form === void 0 ? void 0 : form.dataset.ddmforminstanceid;
    };

    exports.getFormId = getFormId;

    var getFormTitle = function getFormTitle() {
      var _form$querySelector;

      var form = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : document;
      var title = form === null || form === void 0 ? void 0 : (_form$querySelector = form.querySelector('[data-form-title]')) === null || _form$querySelector === void 0 ? void 0 : _form$querySelector.dataset.formTitle;
      return Liferay.Util.escape(title);
    };

    exports.getFormTitle = getFormTitle;
    //# sourceMappingURL=formId.es.js.map
  }
});
//# sourceMappingURL=formId.es.js.map

==> com.liferay.dynamic.data.mapping.form.renderer-5.0.73.jar: META-INF/resources/js/util/formId.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@5.0.73/js/util/formId.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-dom'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.getFormTitle = exports.getFormId = exports.getFormNode = void 0;

    var _metalDom = _interopRequireDefault(require("frontend-js-metal-web$metal-dom"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    /**
     * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
     * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
     */
    var getFormNode = function getFormNode(element) {
      return _metalDom.default.closest(element, 'form');
    };

    exports.getFormNode = getFormNode;

    var getFormId = function getFormId(form) {
      return form === null || form === void 0 ? void 0 : form.dataset.ddmforminstanceid;
    };

    exports.getFormId = getFormId;

    var getFormTitle = function getFormTitle() {
      var _form$querySelector;

      var form = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : document;
      return form === null || form === void 0 ? void 0 : (_form$querySelector = form.querySelector('.ddm-form-basic-info .ddm-form-name')) === null || _form$querySelector === void 0 ? void 0 : _form$querySelector.innerHTML;
    };

    exports.getFormTitle = getFormTitle;
    //# sourceMappingURL=formId.es.js.map
  }
});
//# sourceMappingURL=formId.es.js.map
